@@ -2,6 +2,7 @@ package files_test
 
 import (
 	"fmt"
+	"io/fs"
 	"os"
 	"path/filepath"
 	"runtime"
@@ -160,7 +161,7 @@ contents:
 	require.Equal(t, "files_test.go", f.Source)
 	require.Equal(t, "/b", f.Destination)
 	require.Equal(t, f.FileInfo.Mode, fi.Mode())
-	require.Equal(t, f.FileInfo.MTime, fi.ModTime())
+	require.Equal(t, f.FileInfo.MTime, mtime)
 }
 
 func TestFileInfo(t *testing.T) {
@@ -896,6 +897,34 @@ func TestTree(t *testing.T) {
 	}, withoutFileInfo(results))
 }
 
+func TestTreeMode(t *testing.T) {
+	results, err := files.PrepareForPackager(
+		files.Contents{
+			{
+				Source:      filepath.Join("testdata", "tree"),
+				Destination: "/usr/share/foo",
+				Type:        files.TypeTree,
+				FileInfo: &files.ContentFileInfo{
+					Mode: 0o777,
+				},
+			},
+		},
+		0,
+		"",
+		false,
+		mtime,
+	)
+	require.NoError(t, err)
+
+	for _, f := range results {
+		if f.Destination == "/usr/" || f.Destination == "/usr/share/" || f.Type == files.TypeSymlink {
+			require.NotEqual(t, fs.FileMode(0o777).String(), f.FileInfo.Mode.String(), f.Destination)
+			continue
+		}
+		require.Equal(t, fs.FileMode(0o777).String(), f.FileInfo.Mode.String(), "%s: %s", f.Destination, f.Type)
+	}
+}
+
 func withoutFileInfo(contents files.Contents) files.Contents {
 	filtered := make(files.Contents, 0, len(contents))
 
