@@ -17,11 +17,12 @@ import (
 	"github.com/goreleaser/chglog"
 	"github.com/goreleaser/nfpm/v2"
 	"github.com/goreleaser/nfpm/v2/files"
+	"github.com/goreleaser/nfpm/v2/internal/sign"
 	"github.com/stretchr/testify/require"
 )
 
 func exampleInfo() *nfpm.Info {
-	return nfpm.WithDefaults(&nfpm.Info{
+	return setDefaults(nfpm.WithDefaults(&nfpm.Info{
 		Name:        "foo",
 		Arch:        "amd64",
 		Description: "Foo does things",
@@ -84,7 +85,7 @@ func exampleInfo() *nfpm.Info {
 				},
 			},
 		},
-	})
+	}))
 }
 
 func TestConventionalExtension(t *testing.T) {
@@ -366,20 +367,20 @@ func TestRPMVersionWithReleaseAndPrerelease(t *testing.T) {
 	info := exampleInfo()
 
 	info.Version = "1.0.0"
-	info.Release = "0.2"
+	info.Release = "2"
 	info.Prerelease = "rc1"
 	meta, err := buildRPMMeta(info)
 	require.NoError(t, err)
 	require.Equal(t, "1.0.0~rc1", meta.Version)
-	require.Equal(t, "0.2", meta.Release)
+	require.Equal(t, "2", meta.Release)
 
 	info.Version = "1.0.0~rc1"
-	info.Release = "0.2"
+	info.Release = "3"
 	info.Prerelease = ""
 	meta, err = buildRPMMeta(info)
 	require.NoError(t, err)
 	require.Equal(t, "1.0.0~rc1", meta.Version)
-	require.Equal(t, "0.2", meta.Release)
+	require.Equal(t, "3", meta.Release)
 }
 
 func TestRPMVersionWithVersionMetadata(t *testing.T) {
@@ -388,15 +389,18 @@ func TestRPMVersionWithVersionMetadata(t *testing.T) {
 
 	info.Version = "1.0.0+meta"
 	info.VersionMetadata = ""
-	meta, err := buildRPMMeta(nfpm.WithDefaults(info))
+	meta, err := buildRPMMeta(info)
 	require.NoError(t, err)
 	require.Equal(t, "1.0.0+meta", meta.Version)
+	require.Equal(t, "1", meta.Release)
 
 	info.Version = "1.0.0"
 	info.VersionMetadata = "meta"
+	info.Release = "10"
 	meta, err = buildRPMMeta(nfpm.WithDefaults(info))
 	require.NoError(t, err)
 	require.Equal(t, "1.0.0+meta", meta.Version)
+	require.Equal(t, "10", meta.Release)
 }
 
 func TestWithInvalidEpoch(t *testing.T) {
@@ -503,7 +507,7 @@ func TestArches(t *testing.T) {
 		t.Run(k, func(t *testing.T) {
 			info := exampleInfo()
 			info.Arch = k
-			info = ensureValidArch(info)
+			info = setDefaults(info)
 			require.Equal(t, archToRPM[k], info.Arch)
 		})
 	}
@@ -511,7 +515,7 @@ func TestArches(t *testing.T) {
 	t.Run("override", func(t *testing.T) {
 		info := exampleInfo()
 		info.RPM.Arch = "foo64"
-		info = ensureValidArch(info)
+		info = setDefaults(info)
 		require.Equal(t, "foo64", info.Arch)
 	})
 }
@@ -568,7 +572,7 @@ func TestRPMConventionalFileName(t *testing.T) {
 	}{
 		{
 			Version: "1.2.3", Release: "", Prerelease: "", Metadata: "",
-			Expected: fmt.Sprintf("%s-1.2.3.%s.rpm", info.Name, info.Arch),
+			Expected: fmt.Sprintf("%s-1.2.3-1.%s.rpm", info.Name, info.Arch),
 		},
 		{
 			Version: "1.2.3", Release: "4", Prerelease: "", Metadata: "",
@@ -580,7 +584,7 @@ func TestRPMConventionalFileName(t *testing.T) {
 		},
 		{
 			Version: "1.2.3", Release: "", Prerelease: "5", Metadata: "",
-			Expected: fmt.Sprintf("%s-1.2.3~5.%s.rpm", info.Name, info.Arch),
+			Expected: fmt.Sprintf("%s-1.2.3~5-1.%s.rpm", info.Name, info.Arch),
 		},
 		{
 			Version: "1.2.3", Release: "1", Prerelease: "5", Metadata: "git",
@@ -740,7 +744,33 @@ func TestRPMSignatureError(t *testing.T) {
 	require.Error(t, err)
 
 	var expectedError *nfpm.ErrSigningFailure
-	require.True(t, errors.As(err, &expectedError))
+	require.ErrorAs(t, err, &expectedError)
+}
+
+func TestRPMSignatureCallback(t *testing.T) {
+	info := exampleInfo()
+	info.RPM.Signature.SignFn = func(r io.Reader) ([]byte, error) {
+		data, err := io.ReadAll(r)
+		if err != nil {
+			return nil, err
+		}
+		return sign.PGPSignerWithKeyID("../internal/sign/testdata/privkey.asc", "hunter2", nil)(data)
+	}
+
+	pubkeyFileContent, err := os.ReadFile("../internal/sign/testdata/pubkey.gpg")
+	require.NoError(t, err)
+
+	keyring, err := openpgp.ReadKeyRing(bytes.NewReader(pubkeyFileContent))
+	require.NoError(t, err)
+	require.NotNil(t, keyring, "cannot verify sigs with an empty keyring")
+
+	var rpmBuffer bytes.Buffer
+	err = Default.Package(info, &rpmBuffer)
+	require.NoError(t, err)
+
+	_, sigs, err := rpmutils.Verify(bytes.NewReader(rpmBuffer.Bytes()), keyring)
+	require.NoError(t, err)
+	require.Len(t, sigs, 2)
 }
 
 func TestRPMGhostFiles(t *testing.T) {
@@ -862,7 +892,7 @@ func TestDirectories(t *testing.T) {
 	// claiming explicit ownership of /etc/bar which already contains a file
 	h, err := extractFileHeaderFromRpm(rpmFileBuffer.Bytes(), "/etc/bar")
 	require.NoError(t, err)
-	require.NotEqual(t, h.Mode()&int(tagDirectory), 0)
+	require.NotEqual(t, 0, h.Mode()&int(tagDirectory))
 
 	// creating an empty folder (which also implies ownership)
 	h, err = extractFileHeaderFromRpm(rpmFileBuffer.Bytes(), "/etc/baz")
@@ -901,7 +931,7 @@ func TestIgnoreUnrelatedFiles(t *testing.T) {
 	err := Default.Package(info, &rpmFileBuffer)
 	require.NoError(t, err)
 
-	require.Len(t, getTree(t, rpmFileBuffer.Bytes()), 0)
+	require.Empty(t, getTree(t, rpmFileBuffer.Bytes()))
 }
 
 func extractFileFromRpm(rpm []byte, filename string) ([]byte, error) {
